summaryrefslogtreecommitdiffstats
path: root/libkdchart/KDChartParams.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdchart/KDChartParams.cpp')
-rw-r--r--libkdchart/KDChartParams.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/libkdchart/KDChartParams.cpp b/libkdchart/KDChartParams.cpp
index aac8928..deedda9 100644
--- a/libkdchart/KDChartParams.cpp
+++ b/libkdchart/KDChartParams.cpp
@@ -707,7 +707,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
break;
++i;
}while( properties(id, propSet) );
// retrieve marker tqalignment
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnMarkerAlign( id, markerAlign ) ){
@@ -750,7 +750,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// extra lines:
// retrieve tqalignment of extra lines
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnExtraLinesAlign( id, extraLinesAlign ) ){
@@ -813,7 +813,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// markers at the ends of the extra lines:
// retrieve marker tqalignment
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnExtraMarkersAlign( id, extraMarkersAlign ) ){
@@ -976,7 +976,7 @@ aligned to.
This must be a reasonable combination of TQt::AlignmentFlags.
\param negativeDeltaX The X distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -987,7 +987,7 @@ size of the chart and the specification made via parameter \c size.
\param negativeDeltaY The Y distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1002,7 +1002,7 @@ special values that you might find usefull for Pie charts or for
Ring charts: \c KDCHART_SAGGITAL_ROTATION and \c
KDCHART_TANGENTIAL_ROTATION both leading to individual
calculation of appropriate rotation for each data value. Rotation
-will be performed around the internal <b>tqalignment point</b> of the
+will be performed around the internal <b>alignment point</b> of the
text -- specified by \c negativeAlign (or \c positiveAlign, resp.).
The following parameters apply to values greater than zero or equal zero:
@@ -1013,7 +1013,7 @@ aligned to.
This must be a reasonable combination of TQt::AlignmentFlags.
\param negativeDeltaX The X distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1023,7 +1023,7 @@ delta value are calculated dynamically before painting based on the
size of the chart and the specification made via parameter \c size.
\param positiveDeltaY The Y distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>tqalignment point</b>
+ positivePosition, resp.) -- and the internal <b>alignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1038,7 +1038,7 @@ special values that you might find usefull for Pie charts or for
Ring charts: \c KDCHART_SAGGITAL_ROTATION and \c
KDCHART_TANGENTIAL_ROTATION both leading to individual
calculation of appropriate rotation for each data value. Rotation
-will be performed around the internal <b>tqalignment point</b> of the
+will be performed around the internal <b>alignment point</b> of the
text -- specified by \c negativeAlign (or \c positiveAlign, resp.).
\param layoutPolicy The way to handle too narrow space conflicts:
@@ -1872,10 +1872,10 @@ TQString KDChartParams::dataRegionFrameAreaName( uint dataRow,
uint data3rd )
{
return TQString( "%1/%2/%3/%4" )
- .tqarg( KDChartEnums::AreaChartDataRegion, 5 )
- .tqarg( dataRow, 5 )
- .tqarg( dataCol, 5 )
- .tqarg( data3rd, 5 );
+ .arg( KDChartEnums::AreaChartDataRegion, 5 )
+ .arg( dataRow, 5 )
+ .arg( dataCol, 5 )
+ .arg( data3rd, 5 );
}
@@ -2609,7 +2609,7 @@ const KDChartParams::KDChartFrameSettings* KDChartParams::frameSettings( uint ar
{
if( pIterIdx )
*pIterIdx = 0;
- const TQString key( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ) );
+ const TQString key( TQString( "%1/-----/-----/-----" ).arg( area, 5 ) );
KDChartFrameSettings* it = _areaDict.find( key );
bFound = ( it != 0 );
if( bFound )
@@ -2643,7 +2643,7 @@ const KDChartParams::KDChartFrameSettings* KDChartParams::frameSettings( uint ar
*/
bool KDChartParams::removeFrame( uint area )
{
- return _areaDict.remove( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ) );
+ return _areaDict.remove( TQString( "%1/-----/-----/-----" ).arg( area, 5 ) );
}
@@ -4617,7 +4617,7 @@ void KDChartParams::setThreeDBarAngle( uint angle )
point. Only used if chartType() == Line and if threeDLines() ==
false. The default is not to draw markers.
- \note Use the setLineMarkerStyle function to specify the tqshape
+ \note Use the setLineMarkerStyle function to specify the shape
of the markers, use the setLineWidth function to set the
width of the lines connecting the markers (or to surpress
drawing of such lines, resp.)
@@ -7487,7 +7487,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use those sections to show some marginal information
like department name, print date, page number... <br>
<b>Note:</b> Those headers <b>share the same area</b> so make sure to
- specify propper horizontal tqalignment for each section when using more than
+ specify propper horizontal alignment for each section when using more than
one of them. By default \c HdFtPosHeader0 has centered alignement,
\c HdFtPosHeader0L is aligned to the left and \c HdFtPosHeader0R to the
right side. All of them are vertically aligned to the bottom, you may
@@ -7504,7 +7504,7 @@ void KDChartParams::setAxisParams( uint n,
You could use this headers to show the main information such as project name,
chart title or period of time (e.g. census year). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
\li Up to three <b>additional headers</b> ( \c HdFtPosHeader2 , \c
@@ -7513,7 +7513,7 @@ void KDChartParams::setAxisParams( uint n,
This headers could show additional information such as project phase, chart
sub-title or sub-period of time (e.g. census quarter-year). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
<p>
@@ -7524,7 +7524,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use these footers instead of (or additional to) the
main header(s) for showing the main information... <br>
Like their header-counterparts they share the same part of the printable area
- so the restrictions regarding tqalignment mentioned above apply also to these
+ so the restrictions regarding alignment mentioned above apply also to these
three sections.
\li Up to three <b>additional footers</b> ( \c HdFtPosFooter2 , \c
@@ -7533,7 +7533,7 @@ void KDChartParams::setAxisParams( uint n,
This footers could show additional information instead of (or additional to)
the additional header(s). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
\li Up to three <b>trailing footers</b> ( \c HdFtPosFooter0 , \c
@@ -7542,7 +7542,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use those sections to show some marginal information
instead of (or additional to) the leading header(s). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding tqalignment mentioned above apply also to these three
+ restrictions regarding alignment mentioned above apply also to these three
sections.
\note The names \c HdFtPosHeader or \c HdFtPosFooter are the basic names also returned by \c basicAxisPos.
@@ -707,7 +707,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
}while( properties(id, propSet) );
- // retrieve marker tqalignment
+ // retrieve marker alignment
propSet.deepCopy( &startSet ); i=0;
do{
@@ -750,7 +750,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// extra lines:
- // retrieve tqalignment of extra lines
+ // retrieve alignment of extra lines
propSet.deepCopy( &startSet ); i=0;
do{
@@ -813,7 +813,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// markers at the ends of the extra lines:
- // retrieve marker tqalignment
+ // retrieve marker alignment
propSet.deepCopy( &startSet ); i=0;
do{